@@ -2,16 +2,18 @@ mod linked_list_mapper;
 mod map_mapper;
 mod map_storage_mapper;
 mod mapper;
+mod queue_mapper;
 mod set_mapper;
 mod single_value_mapper;
 mod token_attributes_mapper;
 mod user_mapper;
 mod vec_mapper;
 
-pub use linked_list_mapper::LinkedListMapper;
+pub use linked_list_mapper::{LinkedListMapper, LinkedListNode};
 pub use map_mapper::MapMapper;
 pub use map_storage_mapper::MapStorageMapper;
 pub use mapper::{StorageClearable, StorageMapper};
+pub use queue_mapper::QueueMapper;
 pub use set_mapper::SetMapper;
 pub use single_value_mapper::SingleValueMapper;
 pub use token_attributes_mapper::TokenAttributesMapper;
