@@ -2,6 +2,7 @@ mod boxed_bytes;
 mod code_metadata;
 mod esdt_local_role;
 mod esdt_token_data;
+mod esdt_token_payment;
 mod esdt_token_type;
 mod h256;
 mod h256_address;
@@ -12,6 +13,7 @@ pub use boxed_bytes::BoxedBytes;
 pub use code_metadata::CodeMetadata;
 pub use esdt_local_role::EsdtLocalRole;
 pub use esdt_token_data::EsdtTokenData;
+pub use esdt_token_payment::EsdtTokenPayment;
 pub use esdt_token_type::EsdtTokenType;
 pub use h256::H256;
 pub use h256_address::Address;
