@@ -8,11 +8,11 @@ use crate::{
 
 use super::ManagedBufferNestedDecodeInput;
 
-impl<'a, M> TopDecodeInput for &'a ManagedBuffer<M>
+impl<M> TopDecodeInput for ManagedBuffer<M>
 where
-    M: ManagedTypeApi + 'static,
+    M: ManagedTypeApi,
 {
-    type NestedBuffer = ManagedBufferNestedDecodeInput<M, &'a ManagedBuffer<M>>;
+    type NestedBuffer = ManagedBufferNestedDecodeInput<M>;
 
     fn byte_len(&self) -> usize {
         self.len()
@@ -29,10 +29,11 @@ where
     {
         if let Some(result) = try_execute_then_cast(|| self.clone()) {
             Ok(result)
-        } else if let Some(result) = try_execute_then_cast(|| BigUint::from_bytes_be_buffer(self)) {
+        } else if let Some(result) = try_execute_then_cast(|| BigUint::from_bytes_be_buffer(&self))
+        {
             Ok(result)
         } else if let Some(result) =
-            try_execute_then_cast(|| BigInt::from_signed_bytes_be_buffer(self))
+            try_execute_then_cast(|| BigInt::from_signed_bytes_be_buffer(&self))
         {
             Ok(result)
         } else {
@@ -44,31 +45,3 @@ where
         ManagedBufferNestedDecodeInput::new(self)
     }
 }
-
-// TODO: find a way to avoid the duplication.
-impl<M> TopDecodeInput for ManagedBuffer<M>
-where
-    M: ManagedTypeApi,
-{
-    type NestedBuffer = ManagedBufferNestedDecodeInput<M, ManagedBuffer<M>>;
-
-    fn byte_len(&self) -> usize {
-        self.len()
-    }
-
-    fn into_boxed_slice_u8(self) -> Box<[u8]> {
-        self.to_boxed_bytes().into_box()
-    }
-
-    fn into_specialized<T, F>(self, else_deser: F) -> Result<T, DecodeError>
-    where
-        T: TryStaticCast,
-        F: FnOnce(Self) -> Result<T, DecodeError>,
-    {
-        (&self).into_specialized(|else_self| else_deser(else_self.clone()))
-    }
-
-    fn into_nested_buffer(self) -> Self::NestedBuffer {
-        ManagedBufferNestedDecodeInput::new(self)
-    }
-}
